pub enum UnsizingMetadata {
Length(ConstantExpr),
DirectVTable(ImplExpr),
NestedVTable(DynBinder<ImplExpr>),
Unknown,
}Expand description
The metadata to attach to the newly-unsized ptr.
Variants
Length(ConstantExpr)
Unsize an array to a slice, storing the length as metadata.
DirectVTable(ImplExpr)
Unsize a non-dyn type to a dyn type, adding a vtable pointer as metadata.
NestedVTable(DynBinder<ImplExpr>)
Unsize a dyn-type to another dyn-type, (optionally) indexing within the current vtable.
Unknown
Couldn’t compute