pub struct ClosureArgs {
pub item: ItemRef,
pub kind: ClosureKind,
pub fn_sig: PolyFnSig,
pub upvar_tys: Vec<Ty>,
}Expand description
Reflects [ty::ClosureArgs]
Fields
item: ItemRefkind: ClosureKindThe base kind of this closure. The kinds are ordered by inclusion: any Fn works as an
FnMut, and any FnMut works as an FnOnce.
fn_sig: PolyFnSigThe signature of the function that the closure implements, e.g. fn(A, B, C) -> D.
upvar_tys: Vec<Ty>The set of captured variables. Together they form the state of the closure.
Implementations
Sourceimpl ClosureArgs
impl ClosureArgs
Sourcepub fn iter_upvar_borrows(&self) -> impl Iterator<Item = &Ty>
pub fn iter_upvar_borrows(&self) -> impl Iterator<Item = &Ty>
Iterate over the upvars that are borrows with erased regions. These may require allocating fresh regions.
Sourceimpl ClosureArgs
impl ClosureArgs
pub fn sfrom<'tcx, S>(s: &S, def_id: RDefId, from: GenericArgsRef<'tcx>) -> Selfwhere
S: UnderOwnerState<'tcx>,