pub struct ItemRefContents {
pub def_id: DefId,
pub generic_args: Vec<GenericArg>,
pub impl_exprs: Vec<ImplExpr>,
pub in_trait: Option<ImplExpr>,
pub has_param: bool,
pub has_non_lt_param: bool,
}Expand description
Contents of ItemRef.
Fields
def_id: DefIdThe item being refered to.
generic_args: Vec<GenericArg>The generics passed to the item. If in_trait is Some, these are only the generics of
the method/type/const itself; generics for the traits are available in
in_trait.unwrap().trait.
impl_exprs: Vec<ImplExpr>Witnesses of the trait clauses required by the item, e.g. T: Sized for Option<T> or B: ToOwned for Cow<'a, B>. Same as above, for associated items this only includes clauses
for the item itself.
in_trait: Option<ImplExpr>If we’re referring to a trait associated item, this gives the trait clause/impl we’re referring to.
has_param: boolWhether this contains any reference to a type/lifetime/const parameter.
has_non_lt_param: boolWhether this contains any reference to a type/const parameter.
Implementations